/*
**	File:			SampleFilter.r
**
**	Description:	Resources for SampleFilter.
**
**	Version:		1.0
**
**	Copyright 1999 Apple Computer. All rights reserved.
**
**	You may incorporate this sample code into your applications without
**	restriction, though the sample code has been provided "AS IS" and the
**	responsibility for its operation is 100% yours.  However, what you are
**	not permitted to do is to redistribute the source as "ABC Sample Code"
**	after having made changes. If you're going to re-distribute the source,
**	we require that you make it clear in the source that the code was
**	descended from Apple Sample Code, but that you've made changes.
**
*/

#include "SysTypes.r"
#include "Types.r"

#include "Version.h"
#include "PrintingPlugins.r"
#include "PSOutputFilters.r"
#include "SampleFilterResources.h"

#if qDebug
#define filterCFMName	"SampleFilter.debug"
#else
#define filterCFMName	"SampleFilter"
#endif

resource kPluginResourceInfoType (kPluginResourceInfoID,
#if qNames
	"Plug-In Info",
#endif
	purgeable) {
	{
		// There needs to be an entry here for each plug-in which is built into our file.
		kPSOutputFilterPlugInType, kPSOutputFilterSubtype, filterCFMName,		
	}	
};


resource kPluginInfoType (kPluginInfoID,
#if qNames
	"Plug-in Info String",
#endif
	purgeable) {
	"This is a sample filter that illustrates how to generate a user interface and do a number of PostScript output filtering operations."
};

//Put correct version into string.
resource 'vers' (1, purgeable) {
	kMajorRev,
	kMinorRev,
	kReleaseStage,
	kNonRelease,
	verUS,					
	kShortVersStr
		#if qDebug				// lets see how we built it.
			kqDebug
		#endif
		#if qSym
			kqSym
		#endif
		#if qNames
			kqNames
		#endif
		,
	kShortVersStr 
	",  1999 Apple Computer Incorporated "
	
		#if qDebug				// lets see how we built it.
			kqDebug
		#endif
		#if qSym
			kqSym
		#endif
		#if qNames
			kqNames
		#endif
};

/*
	Supplying a 'desC' resource lets the driver UI code know what items are
	a checkboxes. It then handles checking and unchecking those checkboxes
	automatically.
	
	The 'desC' resource also gives the ranges of grouped radio buttons so
	that the driver UI code can automatically make sure that one in the 
	group is selected and no others.
	
	If you choose to not supply this resource then you'll have to manage
	radio buttons and checkboxes yourself.
*/
resource kPanelDescriptionType (kFirstPanelDITL, purgeable) {
	{	/* array Checkboxes: 1 element. Item 3 is a check box */
		3
	},
	{	/* array Rads: 1 element. Items 5,6,7 are a group of radio buttons */
		5, 7
	}
};

resource 'DITL' (kFirstPanelDITL, purgeable) {
	{	/* array DITLarray: 7 elements */
		/* [1] */
		{8, 16, 46, 164},
		StaticText {
			disabled,
			"Replacement Text for %%For Comment:"
		},
		/* [2] */
		{8, 168, 40, 308},
		EditText {
			enabled,
			"Sample"
		},
		/* [3] */
		{52, 16, 76, 264},
		CheckBox {
			enabled,
			"Generate Custom Header Comment"
		},
		/* [4] */
		{88, 20, 108, 188},
		StaticText {
			disabled,
			"Special Pages Comments:"
		},
		/* [5] */
		{112, 20, 128, 180},
		RadioButton {
			enabled,
			"None"
		},
		/* [6] */
		{136, 20, 152, 180},
		RadioButton {
			enabled,
			"Page 1 Only"
		},
		/* [7] */
		{160, 20, 176, 180},
		RadioButton {
			enabled,
			"All Pages"
		}
	}
};

resource 'ALRT' (kNeedTextALRT, 
#if qNames
	"Not Enough Text Alert",
#endif
purgeable) {
	{332, 326, 436, 698},
	kNeedTextALRT,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, sound1,
		/* [2] */
		OK, visible, sound1,
		/* [3] */
		OK, visible, sound1,
		/* [4] */
		OK, visible, sound1
	},
	noAutoCenter
};

resource 'DITL' (kNeedTextALRT, 
#if qNames
	"Not Enough Text Alert",
#endif
purgeable) {
	{	/* array DITLarray: 2 elements */
		/* [1] */
		{76, 292, 96, 360},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{16, 64, 59, 362},
		StaticText {
			disabled,
			"The %%For replacement text field cannot be blank!"
		}
	}
};

resource 'ALRT' (kTooMuchTextALRT, 
#if qNames
	"Too Much Text Alert",
#endif
purgeable) {
	{332, 326, 436, 698},
	kTooMuchTextALRT,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, sound1,
		/* [2] */
		OK, visible, sound1,
		/* [3] */
		OK, visible, sound1,
		/* [4] */
		OK, visible, sound1
	},
	noAutoCenter
};

resource 'DITL' (kTooMuchTextALRT, 
#if qNames
	"Too Much Text Alert",
#endif
purgeable) {
	{	/* array DITLarray: 2 elements */
		/* [1] */
		{76, 292, 96, 360},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{16, 64, 59, 362},
		StaticText {
			disabled,
			"The %%For replacement text field cannot have more than 50 characters!"
		}
	}
};

resource 'ALRT' (kSETTINGSALRT_ALRT, 
#if qNames
	"Settings Alert",
#endif
purgeable) {
	{332, 326, 428, 651},
	kSETTINGSALRT_ALRT,
	{	/* array: 4 elements */
		/* [1] */
		OK, visible, sound1,
		/* [2] */
		OK, visible, sound1,
		/* [3] */
		OK, visible, sound1,
		/* [4] */
		OK, visible, sound1
	},
	noAutoCenter
};


resource 'DITL' (kSETTINGSALRT_ALRT, 
#if qNames
	"Settings Alert",
#endif
purgeable) {
	{	/* array DITLarray: 3 elements */
		/* [1] */
		{68, 248, 88, 316},
		Button {
			enabled,
			"OK"
		},
		/* [2] */
		{68, 172, 88, 236},
		Button {
			enabled,
			"Cancel"
		},
		/* [3] */
		{4, 60, 60, 320},
		StaticText {
			disabled,
			"The sample filter gets very poor results"
			" if you print with the Black and White s"
			"ettings. Do you want to print anyway?"
		}
	}
};

resource 'STR ' (kPanelMenuName, 
#if qNames
	"Panel Menu Name",
#endif
	purgeable) {
	"Sample Filter Settings"
};
